@@ -2,7 +2,7 @@
 """
 Tencent is pleased to support the open source community by making 蓝鲸智云PaaS平台社区版 (BlueKing PaaS Community
 Edition) available.
-Copyright (C) 2017-2021 THL A29 Limited, a Tencent company. All rights reserved.
+Copyright (C) 2017 THL A29 Limited, a Tencent company. All rights reserved.
 Licensed under the MIT License (the "License"); you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://opensource.org/licenses/MIT
@@ -22,9 +22,11 @@ from typing import Any, List, Optional
 from .context import Context
 from .engine import Engine
 from .eri import ContextValue, EngineRuntimeInterface
+from .eri.models.node import NodeType
 from .template import Template
 from .utils.constants import VAR_CONTEXT_MAPPING
 from .utils.object import Representable
+from .exceptions import InvalidOperationError
 
 logger = logging.getLogger("bamboo_engine")
 
@@ -559,7 +561,7 @@ def get_pipeline_debug_info(runtime: EngineRuntimeInterface, pipeline_id: str):
     """
 
     return {
-        "contex_values": runtime.get_context(pipeline_id),
+        "context_values": runtime.get_context(pipeline_id),
         "processes": runtime.get_process_info_with_root_pipeline(pipeline_id),
     }
 
@@ -643,7 +645,14 @@ def preview_node_inputs(
             root_pipeline_data=root_pipeline_data,
             parent_params=formatted_param_data,
         )
-    raw_inputs = pipeline["activities"][node_id]["component"]["inputs"]
+
+    node_type = pipeline["activities"][node_id]["type"]
+    if node_type == NodeType.ServiceActivity.value:
+        raw_inputs = pipeline["activities"][node_id]["component"]["inputs"]
+    elif node_type == NodeType.SubProcess.value:
+        raw_inputs = pipeline["activities"][node_id]["params"]
+    else:
+        raise InvalidOperationError(f"can not preview inputs for node type: {node_type}")
     raw_inputs = {key: info["value"] for key, info in raw_inputs.items()}
     hydrated_context = context.hydrate(deformat=True)
     inputs = Template(raw_inputs).render(hydrated_context)
